@@ -1,6 +1,6 @@
 package DBIx::Custom;
 
-our $VERSION = '0.1648';
+our $VERSION = '0.1649';
 
 use 5.008001;
 use strict;
@@ -550,14 +550,15 @@ sub select {
                : defined $table ? [$table]
                : [];
     my $columns   = $args{column} || [];
+    $columns = [$columns] unless ref $columns;
     my $selection = $args{selection} || '';
     my $where     = $args{where} || {};
-    my $relation  = $args{relation};
+    my $relation  = $args{relation} || {};
     my $append    = $args{append};
     my $filter    = $args{filter};
 
-    # Relation table
-    if (!$selection && $relation) {
+    # Relation
+    if (!$selection && keys %$relation) {
         foreach my $rcolumn (keys %$relation) {
             my $table1 = (split (/\./, $rcolumn))[0];
             my $table2 = (split (/\./, $relation->{$rcolumn}))[0];
@@ -568,8 +569,8 @@ sub select {
                 $table1_exists = 1 if $table eq $table1;
                 $table2_exists = 1 if $table eq $table2;
             }
-            push @$tables, $table1 unless $table1_exists;
-            push @$tables, $table2 unless $table2_exists;
+            unshift @$tables, $table1 unless $table1_exists;
+            unshift @$tables, $table2 unless $table2_exists;
         }
     }
     
@@ -624,7 +625,7 @@ sub select {
     push @sql, $swhere;
     
     # Relation
-    if (!$selection && $relation) {
+    if (!$selection && keys %$relation) {
         push @sql, $swhere eq '' ? 'where' : 'and';
         foreach my $rcolumn (keys %$relation) {
             my $table1 = (split (/\./, $rcolumn))[0];
@@ -671,6 +672,10 @@ sub select_at {
     my $primary_keys = delete $args{primary_key};
     $primary_keys = [$primary_keys] unless ref $primary_keys;
     
+    # Table
+    croak qq{"table" option must be specified} unless $args{table};
+    my $table = ref $args{table} ? $args{table}->[-1] : $args{table};
+    
     # Where clause
     my $where = {};
     if (exists $args{where}) {
@@ -678,7 +683,7 @@ sub select_at {
         $where_columns = [$where_columns] unless ref $where_columns;
         
         for(my $i = 0; $i < @$primary_keys; $i ++) {
-           $where->{$primary_keys->[$i]} = $where_columns->[$i];
+           $where->{$table . '.' . $primary_keys->[$i]} = $where_columns->[$i];
         }
     }
     elsif (exists $args{param}) {
@@ -776,6 +781,7 @@ sub setup_model {
             }
         }
     );
+    return $self;
 }
 
 our %VALID_UPDATE_ARGS
@@ -1534,19 +1540,22 @@ This is same as L<DBI>'s C<rollback>.
 
 =head2 C<select>
     
-    my $result = $dbi->select(table    => $table,
-                              column   => [@column],
-                              where    => \%where,
-                              append   => $append,
-                              relation => \%relation,
-                              filter   => \%filter,
-                              query    => 1,
-                              selection => $selection);
+    my $result = $dbi->select(
+        table     => $table,
+        column    => [@column],
+        where     => \%where,
+        append    => $append,
+        relation  => \%relation,
+        filter    => \%filter,
+        query     => 1,
+        selection => $selection
+    );
 
 Execute select statement.
 C<select> method have C<table>, C<column>, C<where>, C<append>,
 C<relation> and C<filter> arguments.
 C<table> is a table name.
+C<column> is column names. this is array reference or string.
 C<where> is where clause. this is normally hash reference.
 C<append> is a string added at the end of the SQL statement.
 C<filter> is filters when parameter binding is executed.
